==> bascom-0.0.1.tar.gz: bascom-0.0.1/README.md <==
# bascom

[![Python versions](https://img.shields.io/pypi/pyversions/bascom.svg?color=blue&logo=python&logoColor=white)](https://www.python.org/)
[![PyPI - Version](https://img.shields.io/pypi/v/bascom)](https://pypi.org/project/bascom/)
[![GitHub tag (with filter)](https://img.shields.io/github/v/tag/Tatsh/bascom)](https://github.com/Tatsh/bascom/tags)
[![License](https://img.shields.io/github/license/Tatsh/bascom)](https://github.com/Tatsh/bascom/blob/master/LICENSE.txt)
[![GitHub commits since latest release (by SemVer including pre-releases)](https://img.shields.io/github/commits-since/Tatsh/bascom/v0.0.1/master)](https://github.com/Tatsh/bascom/compare/v0.0.1...master)
[![CodeQL](https://github.com/Tatsh/bascom/actions/workflows/codeql.yml/badge.svg)](https://github.com/Tatsh/bascom/actions/workflows/codeql.yml)
[![QA](https://github.com/Tatsh/bascom/actions/workflows/qa.yml/badge.svg)](https://github.com/Tatsh/bascom/actions/workflows/qa.yml)
[![Tests](https://github.com/Tatsh/bascom/actions/workflows/tests.yml/badge.svg)](https://github.com/Tatsh/bascom/actions/workflows/tests.yml)
[![Coverage Status](https://coveralls.io/repos/github/Tatsh/bascom/badge.svg?branch=master)](https://coveralls.io/github/Tatsh/bascom?branch=master)
[![Documentation Status](https://readthedocs.org/projects/bascom/badge/?version=latest)](https://bascom.readthedocs.org/?badge=latest)
[![pre-commit](https://img.shields.io/badge/pre--commit-enabled-brightgreen?logo=pre-commit&logoColor=white)](https://github.com/pre-commit/pre-commit)
[![mypy](https://www.mypy-lang.org/static/mypy_badge.svg)](http://mypy-lang.org/)
[![Ruff](https://img.shields.io/endpoint?url=https://raw.githubusercontent.com/astral-sh/ruff/main/assets/badge/v2.json)](https://github.com/astral-sh/ruff)
[![Downloads](https://static.pepy.tech/badge/bascom/month)](https://pepy.tech/project/bascom)
[![Stargazers](https://img.shields.io/github/stars/Tatsh/bascom?logo=github&style=flat)](https://github.com/Tatsh/bascom/stargazers)

[![@Tatsh](https://img.shields.io/badge/dynamic/json?url=https%3A%2F%2Fpublic.api.bsky.app%2Fxrpc%2Fapp.bsky.actor.getProfile%2F%3Factor%3Ddid%3Aplc%3Auq42idtvuccnmtl57nsucz72%26query%3D%24.followersCount%26style%3Dsocial%26logo%3Dbluesky%26label%3DFollow%2520%40Tatsh&query=%24.followersCount&style=social&logo=bluesky&label=Follow%20%40Tatsh)](https://bsky.app/profile/Tatsh.bsky.social)
[![Mastodon Follow](https://img.shields.io/mastodon/follow/109370961877277568?domain=hostux.social&style=social)](https://hostux.social/@Tatsh)

Core library that my tools use. At the time all that is included is a simple function
`setup_logging()`. See documentation for more details.

## Installation

### Poetry

```shell
poetry add bascom
```

### Pip

```shell
pip install bascom
```

==> bascom-0.0.3.tar.gz: bascom-0.0.3/README.md <==
# bascom

[![Python versions](https://img.shields.io/pypi/pyversions/bascom.svg?color=blue&logo=python&logoColor=white)](https://www.python.org/)
[![PyPI - Version](https://img.shields.io/pypi/v/bascom)](https://pypi.org/project/bascom/)
[![GitHub tag (with filter)](https://img.shields.io/github/v/tag/Tatsh/bascom)](https://github.com/Tatsh/bascom/tags)
[![License](https://img.shields.io/github/license/Tatsh/bascom)](https://github.com/Tatsh/bascom/blob/master/LICENSE.txt)
[![GitHub commits since latest release (by SemVer including pre-releases)](https://img.shields.io/github/commits-since/Tatsh/bascom/v0.0.3/master)](https://github.com/Tatsh/bascom/compare/v0.0.3...master)
[![CodeQL](https://github.com/Tatsh/bascom/actions/workflows/codeql.yml/badge.svg)](https://github.com/Tatsh/bascom/actions/workflows/codeql.yml)
[![QA](https://github.com/Tatsh/bascom/actions/workflows/qa.yml/badge.svg)](https://github.com/Tatsh/bascom/actions/workflows/qa.yml)
[![Tests](https://github.com/Tatsh/bascom/actions/workflows/tests.yml/badge.svg)](https://github.com/Tatsh/bascom/actions/workflows/tests.yml)
[![Coverage Status](https://coveralls.io/repos/github/Tatsh/bascom/badge.svg?branch=master)](https://coveralls.io/github/Tatsh/bascom?branch=master)
[![Documentation Status](https://readthedocs.org/projects/bascom/badge/?version=latest)](https://bascom.readthedocs.org/?badge=latest)
[![mypy](https://www.mypy-lang.org/static/mypy_badge.svg)](http://mypy-lang.org/)
[![pre-commit](https://img.shields.io/badge/pre--commit-enabled-brightgreen?logo=pre-commit&logoColor=white)](https://github.com/pre-commit/pre-commit)
[![pydocstyle](https://img.shields.io/badge/pydocstyle-enabled-AD4CD3)](http://www.pydocstyle.org/en/stable/)
[![pytest](https://img.shields.io/badge/pytest-zz?logo=Pytest&labelColor=black&color=black)](https://docs.pytest.org/en/stable/)
[![Ruff](https://img.shields.io/endpoint?url=https://raw.githubusercontent.com/astral-sh/ruff/main/assets/badge/v2.json)](https://github.com/astral-sh/ruff)
[![Downloads](https://static.pepy.tech/badge/bascom/month)](https://pepy.tech/project/bascom)
[![Stargazers](https://img.shields.io/github/stars/Tatsh/bascom?logo=github&style=flat)](https://github.com/Tatsh/bascom/stargazers)

[![@Tatsh](https://img.shields.io/badge/dynamic/json?url=https%3A%2F%2Fpublic.api.bsky.app%2Fxrpc%2Fapp.bsky.actor.getProfile%2F%3Factor%3Ddid%3Aplc%3Auq42idtvuccnmtl57nsucz72%26query%3D%24.followersCount%26style%3Dsocial%26logo%3Dbluesky%26label%3DFollow%2520%40Tatsh&query=%24.followersCount&style=social&logo=bluesky&label=Follow%20%40Tatsh)](https://bsky.app/profile/Tatsh.bsky.social)
[![Mastodon Follow](https://img.shields.io/mastodon/follow/109370961877277568?domain=hostux.social&style=social)](https://hostux.social/@Tatsh)

Core library that my tools use. At the time all that is included is a simple function
`setup_logging()`. See documentation for more details.

## Installation

### Poetry

```shell
poetry add bascom
```

### Pip

```shell
pip install bascom
```
